==> mympd_8.0.3.orig.tar.gz: docs/index.md <==
---
layout: page
permalink: /
title: Index
---

<img src="{{ site.baseurl }}/assets/mympd-logo-schriftzug.svg"/>

myMPD is a standalone and mobile friendly web-based MPD client with a tiny footprint and advanced features.

- [Repository](https://github.com/jcorporation/myMPD)
- [Help to improve myMPD](https://github.com/jcorporation/myMPD/issues/167)
- [Q&A](https://github.com/jcorporation/myMPD/discussions/categories/q-a)

To use all myMPD functions you should use the latest stable MPD version.

This documentation is for myMPD version {% include version %}.

## Table of contents

- [Installation]({{ site.baseurl }}/installation/)
  - [Distributions with myMPD]({{ site.baseurl }}/installation/distributions)
  - [Prebuild Packages]({{ site.baseurl }}/installation/prebuild-packages)
  - [Docker]({{ site.baseurl }}/installation/docker)
  - [Compiling]({{ site.baseurl }}/installation/compiling)
- [Configuration]({{ site.baseurl }}/configuration/)
  - [ACL]({{ site.baseurl }}/configuration/acl)
  - [Logging]({{ site.baseurl }}/configuration/logging)
  - [SSL]({{ site.baseurl }}/configuration/ssl)
- [Running]({{ site.baseurl }}/running)
- [Debug]({{ site.baseurl }}/debug)
- [Scripting]({{ site.baseurl }}/scripting/)
  - [Lua table mympd_state]({{ site.baseurl }}/scripting/lua-table-mympd_state)
- [References]({{ site.baseurl }}/references/)
  - [API]({{ site.baseurl }}/references/api/)
  - [Components]({{ site.baseurl }}/references/components)
  - [Custom navbar icons]({{ site.baseurl }}/references/custom-navbar-icons)
  - [Feature matrix]({{ site.baseurl }}/references/feature-matrix)
  - [Filesystem Hierarchy]({{ site.baseurl }}/references/filesystem-hierarchy)
  - [Keyboard-Shortcuts]({{ site.baseurl }}/references/keyboard-shortcuts)
  - [Local playback]({{ site.baseurl }}/references/local-playback)
  - [Pictures]({{ site.baseurl }}/references/pictures)
  - [Published directories]({{ site.baseurl }}/references/published-directories)
  - [Smart playlists]({{ site.baseurl }}/references/smart-playlists)
  - [Sticker]({{ site.baseurl }}/references/sticker)
  - [Tags]({{ site.baseurl }}/references/tags)
  - [Translating]({{ site.baseurl }}/references/translating)
  - [Trigger]({{ site.baseurl }}/references/trigger)
- [Additional topics]({{ site.baseurl }}/additional-topics/)
  - [Behind a reverse proxy]({{ site.baseurl }}/additional-topics/behind-a-reverse-proxy)
  - [Recommended MPD configuration]({{ site.baseurl }}/additional-topics/recommended-mpd-configuration)
- [Known issues]({{ site.baseurl }}/known-issues)

==> mympd_9.3.3.orig.tar.gz: docs/index.md <==
---
layout: page
permalink: /
title: Index
---

<img src="{{ site.baseurl }}/assets/mympd-logo-schriftzug.svg"/>

myMPD is a standalone and mobile friendly web-based MPD client with a tiny footprint and advanced features.

- [GitHub Repository](https://github.com/jcorporation/myMPD)
- [Help to improve myMPD](https://github.com/jcorporation/myMPD/issues/167)
- [Q&A](https://github.com/jcorporation/myMPD/discussions/categories/q-a)

To use all myMPD functions you should use the latest stable MPD version.

This documentation is for myMPD version {% include version %}.

## Table of contents

- [Installation]({{ site.baseurl }}/installation/)
  - [Distributions with myMPD]({{ site.baseurl }}/installation/distributions)
  - [Prebuild Packages]({{ site.baseurl }}/installation/prebuild-packages)
  - [Docker]({{ site.baseurl }}/installation/docker)
  - [Compiling]({{ site.baseurl }}/installation/compiling)
- [Configuration]({{ site.baseurl }}/configuration/)
  - [ACL]({{ site.baseurl }}/configuration/acl)
  - [Logging]({{ site.baseurl }}/configuration/logging)
  - [SSL]({{ site.baseurl }}/configuration/ssl)
  - [Pin protection]({{ site.baseurl }}/configuration/pin-protection)
- [Running]({{ site.baseurl }}/running)
- [Debug]({{ site.baseurl }}/debug)
- [Scripting]({{ site.baseurl }}/scripting/)
  - [Lua table mympd_state]({{ site.baseurl }}/scripting/lua-table-mympd_state)
- [References]({{ site.baseurl }}/references/)
  - [API]({{ site.baseurl }}/references/api/)
  - [Components]({{ site.baseurl }}/references/components)
  - [Custom navbar icons]({{ site.baseurl }}/references/custom-navbar-icons)
  - [Feature matrix]({{ site.baseurl }}/references/feature-matrix)
  - [Filesystem Hierarchy]({{ site.baseurl }}/references/filesystem-hierarchy)
  - [Local playback]({{ site.baseurl }}/references/local-playback)
  - [Lyrics]({{ site.baseurl }}/references/lyrics)
  - [Pictures]({{ site.baseurl }}/references/pictures)
  - [Published directories]({{ site.baseurl }}/references/published-directories)
  - [Smart playlists]({{ site.baseurl }}/references/smart-playlists)
  - [Sticker]({{ site.baseurl }}/references/sticker)
  - [Tags]({{ site.baseurl }}/references/tags)
  - [Translating]({{ site.baseurl }}/references/translating)
  - [Trigger]({{ site.baseurl }}/references/trigger)
  - [Webserver uris]({{ site.baseurl }}/references/webserver-uris)
- [Additional topics]({{ site.baseurl }}/additional-topics/)
  - [Behind a reverse proxy]({{ site.baseurl }}/additional-topics/behind-a-reverse-proxy)
  - [Multiple myMPD instances on same host]({{ site.baseurl }}/additional-topics/multiple-myMPD-instances-on-same-host)
  - [Recommended MPD configuration]({{ site.baseurl }}/additional-topics/recommended-mpd-configuration)
  - [Scrobble to ListenBrainz]({{ site.baseurl }}/additional-topics/scrobble-to-listenbrainz)
  - [ListenBrainz Feedback]({{ site.baseurl }}/additional-topics/listenbrainz-feedback)
- [Known issues]({{ site.baseurl }}/known-issues)
- [Security]({{ site.baseurl }}/security)
